<?php
/*
NOTICE OF LICENSE

This source file is subject to the NekloEULA that is bundled with this package in the file ICENSE.txt.

It is also available through the world-wide-web at this URL: http://store.neklo.com/LICENSE.txt

Copyright (c)  Neklo (http://store.neklo.com/)
*/


namespace Neklo\Scheduler\Model;

use Magento\Framework\Model\AbstractModel;
use Magento\Framework\DataObject\IdentityInterface;
use Neklo\Scheduler\Api\Data\JobInterface;
use Neklo\Scheduler\Model\ResourceModel\Schedule\CollectionFactory;

class Job extends AbstractModel implements IdentityInterface, JobInterface
{
    const CACHE_TAG = 'neklo_cronjob';

    protected $_eventPrefix = 'neklo_cronjob';

    private $schedules;

    /**
     * @var \Neklo\Scheduler\Model\ResourceModel\Schedule\CollectionFactory
     */
    protected $scheduleColFactory;

    /**
     * Define resource model
     */
    protected function _construct()
    {
        $this->_init('Neklo\Scheduler\Model\ResourceModel\Job');
    }

    public function disable()
    {
        $this->setData(JobInterface::JOB_ENABLED, false);
        return $this;
    }

    public function enable()
    {
        $this->setData(JobInterface::JOB_ENABLED, true);
        return $this;
    }

    public function isEnabled()
    {
        return $this->getData(JobInterface::JOB_ENABLED);
    }

    /**
     * Get identities
     *
     * @return array
     */
    public function getIdentities()
    {
        $identities = [self::CACHE_TAG . '_' . $this->getId()];
        return $identities;
    }

    public function getSchedules()
    {
        if (!$this->schedules) {
            /** @var $schedule \Neklo\Scheduler\Model\ResourceModel\Schedule\Collection */
            $schedule = $this->getResourceCollection();
            $this->schedules = $schedule;
        }

        return $this->schedules;
    }
}
