<?php
/*
NOTICE OF LICENSE

This source file is subject to the NekloEULA that is bundled with this package in the file ICENSE.txt.

It is also available through the world-wide-web at this URL: http://store.neklo.com/LICENSE.txt

Copyright (c)  Neklo (http://store.neklo.com/)
*/


namespace Neklo\Scheduler\Setup;

use Magento\Framework\Setup\InstallSchemaInterface;
use Magento\Framework\Setup\ModuleContextInterface;
use Magento\Framework\Setup\SchemaSetupInterface;
use Neklo\Scheduler\Api\Data\JobInterface;
use Magento\Framework\DB\Ddl\Table;

class InstallSchema implements InstallSchemaInterface
{
    /**
     * @var SchemaSetupInterface
     */
    private $schema;

    /**
     * @var ModuleContextInterface
     */
    private $context;

    /**
     * Installs DB schema for a module
     *
     * @param  SchemaSetupInterface   $setup
     * @param  ModuleContextInterface $context
     * @return void
     */
    public function install(
        SchemaSetupInterface $setup,
        ModuleContextInterface $context
    ) {
        $this->schema = $setup;
        $this->context = $context;
        $this->schema->startSetup();
        $this->createJobsTable();
        $this->schema->endSetup();
    }

    /**
     * Create table for Jobs
     */
    private function createJobsTable()
    {
        $inst = $this->schema;
        $tableName = $inst->getTable(JobInterface::TABLE_NAME);

        $table = $inst->getConnection()->newTable($tableName);

        $table->addColumn(
            JobInterface::JOB_ID,
            Table::TYPE_SMALLINT,
            null,
            [
                'identity' => true,
                'unsigned' => true,
                'nullable' => false,
                'primary'  => true,
            ],
            'job id'
        );
        $table->addColumn(
            JobInterface::JOB_NAME,
            Table::TYPE_TEXT,
            255,
            ['nullable' => false],
            'Job name'
        );
        $table->addColumn(
            JobInterface::JOB_CLASS,
            Table::TYPE_TEXT,
            255,
            ['nullable' => false],
            'Job class name'
        );
        $table->addColumn(
            JobInterface::JOB_METHOD,
            Table::TYPE_TEXT,
            60,
            ['nullable' => false],
            'Job class method name'
        );
        $table->addColumn(
            JobInterface::JOB_SCHEDULE,
            Table::TYPE_TEXT,
            60,
            ['nullable' => true],
            'Schedule string'
        );
        $table->addColumn(
            JobInterface::JOB_CONFIG,
            Table::TYPE_TEXT,
            255,
            ['nullable' => true],
            'Cron config path'
        );
        $table->addColumn(
            JobInterface::JOB_GROUP,
            Table::TYPE_TEXT,
            60,
            ['nullable' => true],
            'Job group name'
        );
        $table->addColumn(
            JobInterface::JOB_ENABLED,
            Table::TYPE_BOOLEAN,
            null,
            ['nullable' => false],
            'Job enabled'
        );

        $table->setComment('Cron Jobs Table');

        $inst->getConnection()->createTable($table);
    }
}
